@@ -1,4 +1,4 @@
-# $Id$
+# $Id: PDF.pm 6 2005-10-27 01:43:47Z daisuke $
 #
 # Copyright (c) 2005 Daisuke Maki <dmaki@cpan.org>
 # All rights reserved.
@@ -29,4 +29,12 @@ sub extract
     );
 }
 
-1;
\ No newline at end of file
+1;
+
+__END__
+
+=head1 NAME
+
+File::Extract::PDF - Extract Text From PDF
+
+=cut
\ No newline at end of file
